@@ -5,6 +5,8 @@
 */
 
 #include "themetemplatewidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "themedefaulttemplate.h"
 
 #include <KLocalizedString>
@@ -31,7 +33,7 @@ ThemeTemplateWidget::ThemeTemplateWidget(const QString &title, QWidget *parent)
     auto lay = new QVBoxLayout(this);
     auto lab = new QLabel(title);
     lay->addWidget(lab);
-    mListTemplate = new ThemeTemplateListWidget(QStringLiteral("contactprintthemeeditorrc"));
+    mListTemplate = new ThemeTemplateListWidget(u"contactprintthemeeditorrc"_s);
     mListTemplate->setWhatsThis(i18n("You can drag and drop element on editor to import template"));
     connect(mListTemplate, &ThemeTemplateListWidget::insertTemplate, this, &ThemeTemplateWidget::insertTemplate);
     lay->addWidget(mListTemplate);
