@@ -4,6 +4,8 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "contacteditormainwindow.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "contactconfigurationdialog.h"
 #include "contacteditorpage.h"
 #include "managethemes.h"
@@ -40,7 +42,7 @@ void ContactEditorMainWindow::writeConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    KConfigGroup group = config->group(QStringLiteral("ContactEditorMainWindow"));
+    KConfigGroup group = config->group(u"ContactEditorMainWindow"_s);
     group.writeEntry("Size", size());
     mRecentFileAction->saveEntries(group);
 }
@@ -48,7 +50,7 @@ void ContactEditorMainWindow::writeConfig()
 void ContactEditorMainWindow::readConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group = KConfigGroup(config, QStringLiteral("ContactEditorMainWindow"));
+    KConfigGroup group = KConfigGroup(config, u"ContactEditorMainWindow"_s);
     const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
     if (sizeDialog.isValid()) {
         resize(sizeDialog);
@@ -74,19 +76,19 @@ void ContactEditorMainWindow::setupActions()
 {
     mRecentFileAction = new KRecentFilesAction(i18n("Load Recent Theme..."), this);
     connect(mRecentFileAction, &KRecentFilesAction::urlSelected, this, &ContactEditorMainWindow::slotThemeSelected);
-    actionCollection()->addAction(QStringLiteral("load_recent_theme"), mRecentFileAction);
+    actionCollection()->addAction(u"load_recent_theme"_s, mRecentFileAction);
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup groupConfig = config->group(QStringLiteral("ContactEditorMainWindow"));
+    KConfigGroup groupConfig = config->group(u"ContactEditorMainWindow"_s);
     mRecentFileAction->loadEntries(groupConfig);
 
     mAddExtraPage = new QAction(i18nc("@action", "Add Extra Page..."), this);
     connect(mAddExtraPage, &QAction::triggered, this, &ContactEditorMainWindow::slotAddExtraPage);
-    actionCollection()->addAction(QStringLiteral("add_extra_page"), mAddExtraPage);
+    actionCollection()->addAction(u"add_extra_page"_s, mAddExtraPage);
 
-    if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-        mUploadTheme = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Upload theme..."), this);
+    if (KAuthorized::authorize(u"ghns"_s)) {
+        mUploadTheme = new QAction(QIcon::fromTheme(u"get-hot-new-stuff"_s), i18n("Upload theme..."), this);
         connect(mUploadTheme, &QAction::triggered, this, &ContactEditorMainWindow::slotUploadTheme);
-        actionCollection()->addAction(QStringLiteral("upload_theme"), mUploadTheme);
+        actionCollection()->addAction(u"upload_theme"_s, mUploadTheme);
     }
 
     mNewThemeAction = KStandardActions::openNew(this, &ContactEditorMainWindow::slotNewTheme, actionCollection());
@@ -104,21 +106,21 @@ void ContactEditorMainWindow::setupActions()
     KStandardActions::preferences(this, &ContactEditorMainWindow::slotConfigure, actionCollection());
 
     mInstallTheme = new QAction(i18nc("@action", "Install theme"), this);
-    actionCollection()->addAction(QStringLiteral("install_theme"), mInstallTheme);
+    actionCollection()->addAction(u"install_theme"_s, mInstallTheme);
     connect(mInstallTheme, &QAction::triggered, this, &ContactEditorMainWindow::slotInstallTheme);
 
     mInsertFile = new QAction(i18nc("@action", "Insert File..."), this);
-    actionCollection()->addAction(QStringLiteral("insert_file"), mInsertFile);
+    actionCollection()->addAction(u"insert_file"_s, mInsertFile);
     connect(mInsertFile, &QAction::triggered, this, &ContactEditorMainWindow::slotInsertFile);
 
     mManageTheme = new QAction(i18nc("@action", "Manage themes..."), this);
     connect(mManageTheme, &QAction::triggered, this, &ContactEditorMainWindow::slotManageTheme);
-    actionCollection()->addAction(QStringLiteral("manage_themes"), mManageTheme);
+    actionCollection()->addAction(u"manage_themes"_s, mManageTheme);
 
-    mUpdateView = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Update view"), this);
+    mUpdateView = new QAction(QIcon::fromTheme(u"view-refresh"_s), i18n("Update view"), this);
     actionCollection()->setDefaultShortcut(mUpdateView, QKeySequence(Qt::Key_F5));
     connect(mUpdateView, &QAction::triggered, this, &ContactEditorMainWindow::slotUpdateView);
-    actionCollection()->addAction(QStringLiteral("update_view"), mUpdateView);
+    actionCollection()->addAction(u"update_view"_s, mUpdateView);
 }
 
 void ContactEditorMainWindow::slotConfigure()
@@ -134,7 +136,7 @@ void ContactEditorMainWindow::slotConfigure()
 
 void ContactEditorMainWindow::slotManageTheme()
 {
-    QPointer<GrantleeThemeEditor::ManageThemes> dialog = new GrantleeThemeEditor::ManageThemes(QStringLiteral("kaddressbook/viewertemplates/"), this);
+    QPointer<GrantleeThemeEditor::ManageThemes> dialog = new GrantleeThemeEditor::ManageThemes(u"kaddressbook/viewertemplates/"_s, this);
     dialog->exec();
     delete dialog;
 }
